package com.fs.hospital.mapper;

import java.util.List;
import com.fs.hospital.domain.HospitalOrderLogs;

/**
 * 日志Mapper接口
 * 
 * @author fs
 * @date 2024-03-22
 */
public interface HospitalOrderLogsMapper 
{
    /**
     * 查询日志
     * 
     * @param logsId 日志主键
     * @return 日志
     */
    public HospitalOrderLogs selectHospitalOrderLogsByLogsId(Long logsId);

    /**
     * 查询日志列表
     * 
     * @param hospitalOrderLogs 日志
     * @return 日志集合
     */
    public List<HospitalOrderLogs> selectHospitalOrderLogsList(HospitalOrderLogs hospitalOrderLogs);

    /**
     * 新增日志
     * 
     * @param hospitalOrderLogs 日志
     * @return 结果
     */
    public int insertHospitalOrderLogs(HospitalOrderLogs hospitalOrderLogs);

    /**
     * 修改日志
     * 
     * @param hospitalOrderLogs 日志
     * @return 结果
     */
    public int updateHospitalOrderLogs(HospitalOrderLogs hospitalOrderLogs);

    /**
     * 删除日志
     * 
     * @param logsId 日志主键
     * @return 结果
     */
    public int deleteHospitalOrderLogsByLogsId(Long logsId);

    /**
     * 批量删除日志
     * 
     * @param logsIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHospitalOrderLogsByLogsIds(Long[] logsIds);
}
